==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Ellipse/EllipseArcCPPA/ts/EllipseArcCPPA_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>EllipseArcCPPA</name>
    <message>
        <location filename="../EllipseArcCPPA.js" line="+74"/>
        <source>Center</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Wskaż środek
Łuk: środek, punkt, kąty</translatorcomment>
        <translation type="unfinished">Wyśrodkuj</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Major point of ellipse or major radius</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Głównym punktem elipsy lub promień głównej</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Major point of ellipse</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Głównym punktem elipsy</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Minor point of ellipse or minor radius</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Minor punkt promienia elipsy lub drobne</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Minor point of ellipse</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Minor punkt elipsy</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Rotation angle</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź kąt obrotu:
Wprowadź kąt obrotu
Kąt obracania</translatorcomment>
        <translation type="unfinished">Kąt obracania</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Start parameter</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Kliknij parametr</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>End parameter</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Parametr End</translation>
    </message>
    <message>
        <location line="+264"/>
        <source>Invalid major radius.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Nieprawidłowy główny promień.</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Major radius:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Główne promień:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Angle:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź kąt:
Wskaż położenie linii wymiarowej:</translatorcomment>
        <translation type="unfinished">Kąt:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Minor radius:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Mniejszy promień:</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Start angle:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wskaż kąt początkowy:
Kąt początkowy:</translatorcomment>
        <translation type="unfinished">Kąt początkowy:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>End angle:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Kąt końcowy:</translatorcomment>
        <translation type="unfinished">Kąt końcowy:</translation>
    </message>
    <message>
        <location filename="../EllipseArcCPPA.ui" line="+17"/>
        <source>Direction:</source>
        <translatorcomment>--ignored colon--
--file: qt_pl.ts--
Kierunek widoku:</translatorcomment>
        <translation type="unfinished">Kierunek:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Counter Clockwise (positive)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Counter Clockwise (pozytywny)</translation>
    </message>
    <message>
        <location line="+13"/>
        <location line="+17"/>
        <source>Direction</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Kierunek widoku:
Kierunek widoku
LTR</translatorcomment>
        <translation type="unfinished">Kierunek</translation>
    </message>
    <message>
        <location line="-10"/>
        <source>Clockwise (Negative)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Ruchu wskazówek zegara (Negative)</translation>
    </message>
    <message>
        <location filename="../EllipseArcCPPAInit.js" line="+2"/>
        <source>&amp;Ellipse Arc</source>
        <translatorcomment>--google--
Łuk &amp;elipsoidalny (oś)</translatorcomment>
        <translation type="unfinished">Ellipse Arc</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw ellipse arc from center, major point, ratio and angles</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Rysowanie łuku elipsy z centrum, punkt główny, proporcji i kątów</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Ellipse/EllipseArcCPPA/ts/EllipseArcCPPA_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>EllipseArcCPPA</name>
    <message>
        <location filename="../EllipseArcCPPA.js" line="+74"/>
        <source>Center</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Wskaż środek
Łuk: środek, punkt, kąty</translatorcomment>
        <translation>Środek</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Major point of ellipse or major radius</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Główny punkt elipsy lub większy promień</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Major point of ellipse</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Główny punkt elipsy</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Minor point of ellipse or minor radius</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Drugorzędny punkt elipsy lub mniejszy promień</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Minor point of ellipse</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Drugorzędny punkt elipsy</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Rotation angle</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź kąt obrotu:
Wprowadź kąt obrotu
Kąt obracania</translatorcomment>
        <translation>Kąt obrotu</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Start parameter</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Parametr początkowy</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>End parameter</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Parametr końcowy</translation>
    </message>
    <message>
        <location line="+267"/>
        <source>Invalid major radius.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Nieprawidłowy większy promień.</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Major radius:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Większy promień:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Angle:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź kąt:
Wskaż położenie linii wymiarowej:</translatorcomment>
        <translation>Kąt:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Minor radius:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Mniejszy promień:</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Start angle:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wskaż kąt początkowy:
Kąt początkowy:</translatorcomment>
        <translation>Kąt początkowy:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>End angle:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Kąt końcowy:</translatorcomment>
        <translation>Kąt końcowy:</translation>
    </message>
    <message>
        <location filename="../EllipseArcCPPA.ui" line="+17"/>
        <source>Direction:</source>
        <translatorcomment>--ignored colon--
--file: qt_pl.ts--
Kierunek widoku:</translatorcomment>
        <translation>Kierunek:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Counter Clockwise (positive)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Przeciwny do ruchu wskazówek zegara (w lewo)</translation>
    </message>
    <message>
        <location line="+13"/>
        <location line="+17"/>
        <source>Direction</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Kierunek widoku:
Kierunek widoku
LTR</translatorcomment>
        <translation>Kierunek</translation>
    </message>
    <message>
        <location line="-10"/>
        <source>Clockwise (Negative)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Zgodny z ruchem wskazówek zegara (w prawo)</translation>
    </message>
    <message>
        <location filename="../EllipseArcCPPAInit.js" line="+2"/>
        <source>&amp;Ellipse Arc</source>
        <translatorcomment>--google--
Łuk &amp;elipsoidalny (oś)</translatorcomment>
        <translation>Ł&amp;uk elipsy</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw ellipse arc from center, major point, ratio and angles</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Rysuje łuk elipsy ze środka, przez główny punkt, o danej proporcji i kątach</translation>
    </message>
</context>
</TS>
